"""
Qaptan - Apt configuration GUI in PyQt4 
copyright (c) 2009 v.Harishankar.
Released under the GNU GPL v3 or above
"""

import os.path
import pprint as pp
import string
import cPickle
from PyQt4 import QtCore, QtGui

# import the user interface
from QaptanMainWindow_ui import Ui_QaptanMainWindow

# import the export dialog
from QaptanExportDialog import QaptanExportDialog

# import the exporter class

class QaptanMainWindow (QtGui.QMainWindow):
	main_settings = {}
	aptget_settings = {}
	cdrom_settings = {}
	aptcache_settings = {}
	download_settings = {}
	debug_settings = {}
	debugflag = False
	ui = Ui_QaptanMainWindow ()
		
	def __init__ (self, debugflag):
		# initialize base class
		QtGui.QMainWindow.__init__ (self)
		
		# set the debug flag as needed
		self.debugflag = debugflag
		# set up the UI from the generated pyuic4 interface class
		self.ui.setupUi (self)
		# load the configuration settings from file
		self.load_settings ()
		# update UI from configuration
		self.update_ui_from_settings ()
	
	# Locate CDROM button click event
	def onLocateCDROM (self):
		exist_dir = QtGui.QFileDialog.getExistingDirectory (self, "Locate mount point", "/", \
					QtGui.QFileDialog.ShowDirsOnly)		
		if (exist_dir):
			self.ui.mount_point.setText (exist_dir)
		
	# Main window closing event
	def closeEvent (self, event):
		res = QtGui.QMessageBox.question (self, "Confirm", "Are you sure you wish to quit?", "Yes", "No")
		if res == 0:
			event.accept ()
		else:
			event.ignore ()
	
	# Save settings menu event
	def onSaveSettings (self):
		self.save_settings ()
		
	# Export to apt.conf menu event
	def onExport (self):
		# update the settings from UI
		self.update_settings_from_ui ()
		
		dlg = QaptanExportDialog (self)
		# if the user chooses OK
		if dlg.exec_():
			filename = string.strip (str (dlg.ui.export_filename.text()))
			export_group = { "main" : dlg.ui.export_main.isChecked(), \
							 "aptget" : dlg.ui.export_aptget.isChecked (), \
							 "cdrom" : dlg.ui.export_cdrom.isChecked(), \
							 "cache" : dlg.ui.export_cache.isChecked (), \
							 "download" : dlg.ui.export_download.isChecked (), \
							 "debug" : dlg.ui.export_debug.isChecked () }
			
			# debug mode?
			if self.debugflag:
				pp.pprint (filename)
				pp.pprint (export_group)
			
			# if the filename is empty
			if filename == "":
				QtGui.QMessageBox.critical (self, "Error", "Cannot export settings - no file specified")
			# if the filename is /etc/apt/apt.conf 
			if filename == "/etc/apt/apt.conf":
				QtGui.QMessageBox.critical (self, "Error", "Cannot export directly to /etc/apt/apt.conf! Please create a local copy, review changes and then copy it manually to /etc/apt/apt.conf.")
			# if not even one group of settings is to be exported
			elif (True not in export_group.values ()):
				QtGui.QMessageBox.critical (self, "Error", "You must specify at least one group to export")
			# try to export to file specified
			else:
				self.export_settings (filename, export_group)
				
	# About menu event
	def onAbout (self):
		QtGui.QMessageBox.about(self, "Qaptan", "An apt configuration GUI written in PyQt4.\nLicensed under GNU GPL v3.0 or higher.\n\nAuthor: V.Harishankar <v.harishankar@gmail.com>")
					
	# Save the UI settings to pickled files for persistence
	def save_settings (self):
		# first update settings dictionary from the UI
		self.update_settings_from_ui ()

		try:
			if not os.path.exists (os.path.expanduser("~/.qaptan")):
				os.mkdir (os.path.expanduser("~/.qaptan"))
			
			# dump main tab settings in qaptan-main
			cPickle.dump (self.main_settings, file (os.path.expanduser ("~/.qaptan/qaptan-main"), "wb"), 1)
			# dump apt-get settings in qaptan-aptget
			cPickle.dump (self.aptget_settings, file (os.path.expanduser("~/.qaptan/qaptan-aptget"), "wb"), 1)
			# dump apt-cdrom settings in qaptan-cdrom
			cPickle.dump (self.cdrom_settings, file (os.path.expanduser ("~/.qaptan/qaptan-cdrom"), "wb"), 1)
			# dump apt-cache settings in qaptan-cache
			cPickle.dump (self.aptcache_settings, file (os.path.expanduser("~/.qaptan/qaptan-cache"), "wb"), 1)
			# dump the download settings in qaptan-download
			cPickle.dump (self.download_settings, file (os.path.expanduser("~/.qaptan/qaptan-download"), "wb"), 1)
			# dump the debug settings in qaptan-debug
			cPickle.dump (self.debug_settings, file (os.path.expanduser("~/.qaptan/qaptan-debug"), "wb"), 1)
			
			QtGui.QMessageBox.information (self, "Successfully saved", "Settings saved successfully")
		except IOError, args:
			QtGui.QMessageBox.critical (self, "Error", "Error saving settings!")
			if self.debugflag:
				pp.pprint (args)
		
	# Load the UI settings from picked file -- if the files exist
	def load_settings (self):
		try:
			self.main_settings = cPickle.load (file (os.path.expanduser ("~/.qaptan/qaptan-main"), "rb"))
			self.aptget_settings = cPickle.load (file (os.path.expanduser ("~/.qaptan/qaptan-aptget"), "rb"))
			self.aptcache_settings = cPickle.load (file (os.path.expanduser ("~/.qaptan/qaptan-cache"), "rb"))
			self.cdrom_settings = cPickle.load (file (os.path.expanduser ("~/.qaptan/qaptan-cdrom"), "rb"))
			self.download_settings = cPickle.load (file (os.path.expanduser ("~/.qaptan/qaptan-download"), "rb"))
			self.debug_settings = cPickle.load (file (os.path.expanduser ("~/.qaptan/qaptan-debug"), "rb"))
		except IOError:
			if (self.debugflag):
				print "Could not load some settings. Assuming defaults."
			
		# if debug mode
		if (self.debugflag):
			pp.pprint (self.main_settings)
			pp.pprint (self.aptget_settings)
			pp.pprint (self.cdrom_settings)
			pp.pprint (self.aptcache_settings)
			pp.pprint (self.download_settings)
			pp.pprint (self.debug_settings)
			
	# Exporting the configuration
	def export_settings (self, filename, export_group):
		# try to open file for exporting 
		try:
			f = file (os.path.expanduser(filename), "w")
			
			f.write ("// Warning: this file has been generated by Qaptan - the apt configuration GUI\n")
			f.write ("//          it is recommended that you verify this file manually for correctness\n")
			f.write ("//          before you copy it over to /etc/apt/apt.conf\n")
			f.write ("//          *Never* export this directly to /etc/apt/apt.conf without verifying!\n")
			f.write ("//          If you are unsure about any setting found here, REMOVE it! Apt will\n")
			f.write ("//          default to its internal settings...\n")
			# if the main group is enabled for export
			if export_group["main"]:
				str_mainlist = self.export_to_string ("// Main settings", self.main_settings)
				f.writelines (str_mainlist)
			if export_group["aptget"]:
				str_aptgetlist = self.export_to_string ("// apt-get settings", self.aptget_settings)
				f.writelines (str_aptgetlist)
			if export_group["cdrom"]:
				str_cdrom = self.export_to_string ("// CDROM settings", self.cdrom_settings)
				f.writelines (str_cdrom)
			if export_group["cache"]:
				str_cache = self.export_to_string ("// Cache settings", self.aptcache_settings)
				f.writelines (str_cache)
			if export_group["download"]:
				str_download = self.export_to_string ("// Download settings", self.download_settings)
				f.writelines (str_download)
			if export_group["debug"]:
				str_debug = self.export_to_string ("// Debug settings", self.debug_settings)
				f.writelines (str_debug)

			f.close ()
			
			QtGui.QMessageBox.information (self, "Successfully exported", "The settings have been successfully exported. Please review the exported configuration file carefully before you copy it over /etc/apt/apt.conf")
		
		except IOError, args:
			QtGui.QMessageBox.critical (self, "Error writing file", "File could not be opened for writing or writing failed!")
			if self.debugflag:
				print "Error writing output file"
				pp.pprint (args)
	
	# Generate a string for a group of options
	def export_to_string (self, comment, export_settings):
		str_list = []

		# put the comment
		str_list.append ( str ("\n" + comment + "\n\n" ) )
		
		# now export key value pairs
		for key, value in export_settings.iteritems ():
			# if the type is string, then handle it
			if (type (value) == str):
				# try to see if the item has multiple lines
				if value <> "":
					str_list.append (str (key + " \"" + value + "\";\n"))
			# if the type is a list
			elif (type (value) == list):
				itemhead = True
				for item in value:
					if item <> "":
						if itemhead == True:
							str_list.append (str (key + " \"\";\n"))
							itemhead = False
						str_list.append (str (key + ":: \"" + item + "\";\n"))
			# if the type is the checkstate
			elif type (value) == QtCore.Qt.CheckState or type (value) == int:
				if value == 0:
					str_list.append ( str (key + " \"false\";\n"))
				elif value == 2:
					str_list.append ( str (key + " \"true\";\n"))
						
		return str_list

	# Update the settings dictionaries from the GUI
	def update_settings_from_ui (self):
		self.update_main_from_ui ()
		self.update_aptget_from_ui ()
		self.update_cdrom_from_ui ()
		self.update_cache_from_ui ()
		self.update_download_from_ui ()
		self.update_debug_from_ui ()
	
	# Update the main settings from GUI
	def update_main_from_ui (self):
		
		# If the architecture is specified, then set it
		self.main_settings["APT::Architecture"] = string.strip (str (self.ui.architecture.currentText ()))

		# Get the default release, if specified
		self.main_settings["APT::Default-Release"] = string.strip (str (self.ui.default_release.currentText ()))
		
		# The list of essential packages
		self.main_settings["APT::Build-Essential"] = string.split (string.strip (str (self.ui.build_essential.toPlainText ())), "\n")
		
		# The list of never autoremove packages
		self.main_settings["APT::NeverAutoRemove"] = string.split (string.strip (str (self.ui.never_autoremove.toPlainText ())), "\n")
		
		# get cache limit
		self.main_settings["APT::Cache-Limit"] = string.strip (str (self.ui.cache_limit.text ()))
		
	
		self.main_settings["APT::Clean-Installed"] = self.ui.autoclean.checkState ()
		self.main_settings["APT::Ignore-Hold"] = self.ui.ignore_held.checkState ()
		self.main_settings["quiet"] = self.ui.quiet.checkState ()
		self.main_settings["APT::Immediate-Configure"] =  2 - self.ui.disable_immediate.checkState ()
		self.main_settings["APT::Force-Loopbreak"] = self.ui.force_loopbreak.checkState ()

		# debugging setting
		if (self.debugflag):
			pp.pprint (self.main_settings)
		
	# Update the apt-get settings from GUI
	def update_aptget_from_ui (self):
		self.aptget_settings["APT::Install-Recommends"] = self.ui.install_recommended.checkState ()
		self.aptget_settings["APT::Install-Suggests"] = self.ui.install_suggested.checkState ()
		self.aptget_settings["APT::Get::Download-Only"] = self.ui.download_only.checkState ()
		self.aptget_settings["APT::Get::Fix-Broken"] = self.ui.fix_broken.checkState ()
		self.aptget_settings["APT::Get::Fix-Missing"] = self.ui.fix_missing.checkState ()
		self.aptget_settings["APT::Get::Download"] = 2 - self.ui.dont_download.checkState ()
		self.aptget_settings["APT::Get::Simulate"] = self.ui.simulate.checkState ()
		self.aptget_settings["APT::Get::Show-Upgraded"] = self.ui.show_upgraded.checkState ()
		self.aptget_settings["APT::Get::Upgrade"] = 2 - self.ui.dont_upgrade.checkState ()
		self.aptget_settings["APT::Get::Purge"] = self.ui.purge.checkState ()
		self.aptget_settings["APT::Get::List-Cleanup"] = self.ui.list_cleanup.checkState ()
		self.aptget_settings["APT::Get::Remove"] = 2 - self.ui.dont_remove.checkState ()
		self.aptget_settings["APT::Get::Only-Source"] = self.ui.source_only.checkState ()
		self.aptget_settings["APT::Get::Assume-Yes"] = self.ui.assume_yes.checkState ()
		self.aptget_settings["APT::Get::Compile"] = self.ui.compile_source.checkState ()
		self.aptget_settings["APT::Get::force-yes"] = self.ui.force_yes.checkState ()
		self.aptget_settings["APT::Get::ReInstall"] = self.ui.reinstall.checkState ()
		self.aptget_settings["APT::Get::Trivial-Only"] = self.ui.trivial_only.checkState ()
		self.aptget_settings["APT::Get::AutomaticRemove"] = self.ui.auto_remove.checkState ()
		self.aptget_settings["APT::Get::AllowUnauthenticated"] = self.ui.allow_unauthenticated.checkState ()
		
		# debug mode
		if (self.debugflag):
			pp.pprint (self.aptget_settings)
				
	# Update the cdrom settings from GUI
	def update_cdrom_from_ui (self):
		self.cdrom_settings["Acquire::cdrom::mount"] = string.strip (str (self.ui.mount_point.text ()))
		self.cdrom_settings["APT::CDROM::Rename"] = self.ui.rename_disk.checkState ()
		self.cdrom_settings["APT::CDROM::NoMount"] = self.ui.no_mount.checkState ()
		self.cdrom_settings["APT::CDROM::Fast"] = self.ui.fast_copy.checkState ()
		self.cdrom_settings["APT::CDROM::NoAct"] = self.ui.no_act.checkState ()
		self.cdrom_settings["APT::Authentication::TrustCDROM"] = self.ui.trust_cdrom.checkState ()
		
		#debug mode
		if (self.debugflag):
			pp.pprint (self.cdrom_settings)
				
	# Update the cache settings from the GUI
	def update_cache_from_ui (self):
		self.aptcache_settings["APT::Cache::Important"] = self.ui.display_important_deps.checkState ()
		self.aptcache_settings["APT::Cache::ShowFull"] = self.ui.display_full.checkState ()
		self.aptcache_settings["APT::Cache::AllVersions"] = self.ui.display_all_versions.checkState ()
		self.aptcache_settings["APT::Cache::Generate"] = self.ui.auto_regenerate_cache.checkState ()
		self.aptcache_settings["APT::Cache::AllNames"] = self.ui.display_all_names.checkState ()
		self.aptcache_settings["APT::Cache::RecurseDepends"] = self.ui.recurse_depends.checkState ()
		self.aptcache_settings["APT::Cache::Installed"] = self.ui.limit_installed.checkState ()
		
		#debug mode
		if (self.debugflag):
			pp.pprint (self.aptcache_settings)
		
	# Update the download settings from the GUI
	def update_download_from_ui (self):
		self.download_settings["Acquire::Retries"] =  string.strip (str( self.ui.num_retries.text ()))
		self.download_settings["Acquire::Queue-Mode"] = str (self.ui.queueing_mode.currentText ())
		self.download_settings["Acquire::PDiffs"] = self.ui.use_pdiffs.checkState ()
		self.download_settings["Acquire::Source-Symlinks"] = self.ui.source_symlinks.checkState ()
		
		#debug mode
		if (self.debugflag):
			pp.pprint (self.download_settings)
			
	# Update debug settings from the GUI
	def update_debug_from_ui (self):
		self.debug_settings["Debug::pkgProblemResolver"] = self.ui.debug_resolver.checkState ()
		self.debug_settings["Debug::aptcdrom"] = self.ui.debug_aptcdrom.checkState ()
		self.debug_settings["Debug::NoLocking"] = self.ui.debug_filelock.checkState ()
		self.debug_settings["Debug::BuildDeps"] = self.ui.debug_builddep.checkState ()
		self.debug_settings["Debug::Hashes"] = self.ui.debug_cryptohash.checkState ()
		self.debug_settings["Debug::pkgPolicy"] = self.ui.debug_pkgpolicy.checkState ()
		self.debug_settings["Debug::pkgAutoRemove"] = self.ui.debug_logremoval.checkState ()
		self.debug_settings["Debug::pkgInitConfig"] = self.ui.debug_initconfig.checkState ()
		self.debug_settings["Debug::pkgDPkgProgressReporting"] = self.ui.debug_dpkgprogress.checkState ()
		self.debug_settings["Debug::pkgPackageManager"] = self.ui.debug_dpkgstatus.checkState ()
		self.debug_settings["Debug::Acquire::http"] = self.ui.debug_http.checkState ()
		self.debug_settings["Debug::Acquire::ftp"] = self.ui.debug_ftp.checkState ()
		self.debug_settings["Debug::Acquire::https"] = self.ui.debug_https.checkState ()
		self.debug_settings["Debug::Acquire::cdrom"] = self.ui.debug_cdrom.checkState ()
		self.debug_settings["Debug::Acquire::gpgv"] = self.ui.debug_gpgv.checkState ()
		
		#debug mode
		if (self.debugflag):
			pp.pprint (self.debug_settings)
			
	# Update the UI from the settings
	def update_ui_from_settings (self):
		self.update_ui_main ()
		self.update_ui_aptget ()
		self.update_ui_cdrom ()
		self.update_ui_cache ()
		self.update_ui_download ()
		self.update_ui_debug ()
		
	# Update the UI from main settings
	def update_ui_main (self):
		# always check if the key exists. Sometimes the config files may not exist, so
		# the settings dictionary might not be populated 
		try:
			self.ui.architecture.setEditText (self.main_settings["APT::Architecture"])
			self.ui.default_release.setEditText (self.main_settings["APT::Default-Release"])
			self.ui.build_essential.setPlainText (string.join (self.main_settings["APT::Build-Essential"],"\n"))
			self.ui.never_autoremove.setPlainText (string.join (self.main_settings["APT::NeverAutoRemove"], "\n"))
			self.ui.cache_limit.setText (self.main_settings["APT::Cache-Limit"])
			self.ui.autoclean.setCheckState (self.main_settings["APT::Clean-Installed"])
			self.ui.disable_immediate.setCheckState (2 - self.main_settings["APT::Immediate-Configure"])
			self.ui.ignore_held.setCheckState (self.main_settings["APT::Ignore-Hold"])
			self.ui.force_loopbreak.setCheckState (self.main_settings["APT::Force-Loopbreak"])
			self.ui.quiet.setCheckState (self.main_settings["quiet"])
		except KeyError, args:
			if self.debugflag:
				print "Setting(s) not updated in main settings tab because not found"
				pp.pprint (args)
	
	# Update the UI from aptget settings
	def update_ui_aptget (self):
		# always check if the key exists. Sometimes the config files may not exist, so 
		# the settings dictionary might not be populated
		try:
			self.ui.install_recommended.setCheckState (self.aptget_settings["APT::Install-Recommends"])
			self.ui.install_suggested.setCheckState (self.aptget_settings["APT::Install-Suggests"])
			self.ui.download_only.setCheckState (self.aptget_settings["APT::Get::Download-Only"])
			self.ui.fix_missing.setCheckState (self.aptget_settings["APT::Get::Fix-Missing"])
			self.ui.dont_download.setCheckState (2 - self.aptget_settings["APT::Get::Download"])
			self.ui.simulate.setCheckState (self.aptget_settings["APT::Get::Simulate"])
			self.ui.fix_broken.setCheckState (self.aptget_settings["APT::Get::Fix-Broken"])
			self.ui.assume_yes.setCheckState (self.aptget_settings["APT::Get::Assume-Yes"])
			self.ui.show_upgraded.setCheckState (self.aptget_settings["APT::Get::Show-Upgraded"])
			self.ui.compile_source.setCheckState (self.aptget_settings["APT::Get::Compile"])
			self.ui.dont_upgrade.setCheckState (2 - self.aptget_settings["APT::Get::Upgrade"])
			self.ui.force_yes.setCheckState (self.aptget_settings["APT::Get::force-yes"])
			self.ui.purge.setCheckState (self.aptget_settings["APT::Get::Purge"])
			self.ui.reinstall.setCheckState (self.aptget_settings["APT::Get::ReInstall"])
			self.ui.list_cleanup.setCheckState (self.aptget_settings["APT::Get::List-Cleanup"])
			self.ui.trivial_only.setCheckState (self.aptget_settings["APT::Get::Trivial-Only"])
			self.ui.dont_remove.setCheckState (2 - self.aptget_settings["APT::Get::Remove"])
			self.ui.auto_remove.setCheckState (self.aptget_settings["APT::Get::AutomaticRemove"])
			self.ui.source_only.setCheckState (self.aptget_settings["APT::Get::Only-Source"])
			self.ui.allow_unauthenticated.setCheckState (self.aptget_settings["APT::Get::AllowUnauthenticated"])
		except KeyError, args:
			if self.debugflag:
				print "Settings(s) not updated in apt-get tab because not found"
				pp.pprint (args)
						
	# Update the UI from cdrom settings
	def update_ui_cdrom (self):
		# always check if the key exists. Sometimes the config file may not exist, so 
		# the settings dictionary might not be populated
		try:
			self.ui.mount_point.setText (self.cdrom_settings["Acquire::cdrom::mount"])
			self.ui.rename_disk.setCheckState (self.cdrom_settings["APT::CDROM::Rename"])
			self.ui.no_mount.setCheckState (self.cdrom_settings["APT::CDROM::NoMount"])
			self.ui.fast_copy.setCheckState (self.cdrom_settings["APT::CDROM::Fast"])
			self.ui.no_act.setCheckState (self.cdrom_settings["APT::CDROM::NoAct"])
			self.ui.trust_cdrom.setCheckState (self.cdrom_settings["APT::Authentication::TrustCDROM"])
		except KeyError, args:
			if self.debugflag:
				print "Settings(s) not updated in cdrom tab because not found"
				pp.pprint (args)
		
	# Update the UI from cache settings
	def update_ui_cache (self):
		# always check if the key exists. Sometimes the config file may not exist, so 
		# the settings dictionary might not be populated
		try:
			self.ui.display_important_deps.setCheckState (self.aptcache_settings["APT::Cache::Important"])
			self.ui.display_full.setCheckState (self.aptcache_settings["APT::Cache::ShowFull"])
			self.ui.display_all_versions.setCheckState (self.aptcache_settings["APT::Cache::AllVersions"])
			self.ui.auto_regenerate_cache.setCheckState (self.aptcache_settings["APT::Cache::Generate"])
			self.ui.display_all_names.setCheckState (self.aptcache_settings["APT::Cache::AllNames"])
			self.ui.recurse_depends.setCheckState (self.aptcache_settings["APT::Cache::RecurseDepends"])
			self.ui.limit_installed.setCheckState (self.aptcache_settings["APT::Cache::Installed"])
		except KeyError, args:
			if self.debugflag:
				print "Setting(s) not updated in cache tab because not found"
				pp.pprint (args)
	
	# Update the UI from download settings
	def update_ui_download (self):
		# always check if the key exists. Sometimes the config file may not exist, so 
		# the settings dictionary might not be populated
		try:
			self.ui.num_retries.setText (self.download_settings["Acquire::Retries"])
			self.ui.queueing_mode.setCurrentIndex (self.ui.queueing_mode.findText (self.download_settings["Acquire::Queue-Mode"]))
			self.ui.use_pdiffs.setCheckState (self.download_settings["Acquire::PDiffs"])
			self.ui.source_symlinks.setCheckState (self.download_settings["Acquire::Source-Symlinks"])
		except KeyError, args:
			if self.debugflag:
				print "Setting(s) not updated in download tab because not found"
				pp.pprint (args)
		
	# Update the UI from debug settings 
	def update_ui_debug (self):
		# always check if the key exists. Sometimes the config file may not exist, so 
		# the settings dictionary might not be populated
		try:
			self.ui.debug_resolver.setCheckState (self.debug_settings["Debug::pkgProblemResolver"])
			self.ui.debug_aptcdrom.setCheckState (self.debug_settings["Debug::aptcdrom"])
			self.ui.debug_filelock.setCheckState (self.debug_settings["Debug::NoLocking"])
			self.ui.debug_builddep.setCheckState (self.debug_settings["Debug::BuildDeps"])
			self.ui.debug_cryptohash.setCheckState (self.debug_settings["Debug::Hashes"])
			self.ui.debug_pkgpolicy.setCheckState (self.debug_settings["Debug::pkgPolicy"])
			self.ui.debug_logremoval.setCheckState (self.debug_settings["Debug::pkgAutoRemove"])
			self.ui.debug_initconfig.setCheckState (self.debug_settings["Debug::pkgInitConfig"])
			self.ui.debug_dpkgprogress.setCheckState (self.debug_settings["Debug::pkgDPkgProgressReporting"])
			self.ui.debug_dpkgstatus.setCheckState (self.debug_settings["Debug::pkgPackageManager"])
			self.ui.debug_http.setCheckState (self.debug_settings["Debug::Acquire::http"])
			self.ui.debug_cdrom.setCheckState (self.debug_settings["Debug::Acquire::cdrom"])
			self.ui.debug_ftp.setCheckState (self.debug_settings["Debug::Acquire::ftp"])
			self.ui.debug_gpgv.setCheckState (self.debug_settings["Debug::Acquire::gpgv"])
			self.ui.debug_https.setCheckState (self.debug_settings["Debug::Acquire::https"])
		except KeyError, args:
			if self.debugflag:
				print "Settings not updated in debug tab because not found"
				pp.pprint (args)
	
